@@ -5,7 +5,7 @@ use Sys::Info::Driver::Windows qw( :metrics :WMI );
 
 ## no critic (ValuesAndExpressions::ProhibitMagicNumbers, ValuesAndExpressions::RequireNumberSeparators)
 
-our $VERSION = '0.73';
+our $VERSION = '0.74';
 
 my %VISTA_EDITION = ( # OK
    0x00000006 => q{Business Edition},
@@ -40,9 +40,8 @@ my %SERVER08_EDITION = ( # OK
 
 sub _cpu_arch {
     my $self = shift;
-    require Sys::Info;
-    my $info = Sys::Info->new;
-    my $cpu  = $info->device( 'CPU' );
+    require Sys::Info::Device;
+    my $cpu  = Sys::Info::Device->new( 'CPU' );
     foreach my $cpu ( $cpu->identify ) {
         # get the first available one
         return $cpu->{architecture} if $cpu->{architecture};
@@ -247,8 +246,8 @@ None. Used internally.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.73> of C<Sys::Info::Driver::Windows::OS::Editions>
-released on C<14 January 2010>.
+This document describes version C<0.74> of C<Sys::Info::Driver::Windows::OS::Editions>
+released on C<25 May 2010>.
 
 Although there are not much Windows versions, there are ridiculously lots of
 editions of Windows versions after Windows 2000. This module uses C<WMI>,
